@@ -85,27 +85,12 @@ void CreateClassWizard::setup()
     addPage(d->output = new OutputPage(this));
 }
 
-
-int CreateClassWizard::nextId() const
-{
-    if( ClassIdentifierPage* idpage = dynamic_cast<ClassIdentifierPage*>( currentPage() ) )
-    {
-        if( idpage->inheritanceList().isEmpty() )
-        {
-            return page( idpage->nextId() )->nextId();
-        }
-    }
-    return QWizard::nextId();
-}
-
-
 void CreateClassWizard::accept()
 {
     QWizard::accept();
     
     //Transmit all the final information to the generator
-    d->generator->license(field("license").toString());
-    d->generator->setAddCommentCharToLicense(field("addComment").toBool());
+    d->generator->setLicense(field("license").toString());
     kDebug() << "Header Url: " << field("headerUrl").toString();
     /*
     d->generator->setHeaderUrl(field("headerUrl").toString());
@@ -120,7 +105,7 @@ void CreateClassWizard::accept()
     changes.applyAllChanges();
 }
 
-ClassGenerator * CreateClassWizard::generator(void)
+ClassGenerator * CreateClassWizard::generator()
 {
     return d->generator;
 }
@@ -132,14 +117,13 @@ ClassIdentifierPage* CreateClassWizard::newIdentifierPage()
 
 OverridesPage* CreateClassWizard::newOverridesPage()
 {
-    return new OverridesPage(this);
+    return new OverridesPage(d->generator, this);
 }
 
 struct ClassGeneratorPrivate
 {
     QString name; ///< The name for the class to be generated (does not include namespace if relevant)
     QString license;
-    bool addCommentChar;
     QList<DeclarationPointer> inheritedClasses;   ///< Represent *ALL* of the inherited classes
     SimpleCursor headerPosition;
     SimpleCursor implementationPosition;
@@ -148,34 +132,34 @@ struct ClassGeneratorPrivate
     KUrl implementationUrl;
 };
 
-ClassGenerator::ClassGenerator(void) :
+ClassGenerator::ClassGenerator() :
                              d(new ClassGeneratorPrivate)
 {
 }
 
-ClassGenerator::~ClassGenerator(void)
+ClassGenerator::~ClassGenerator()
 {
     delete d;
 }
 
-const QString & ClassGenerator::name(void) const
+const QString & ClassGenerator::name() const
 {
     return d->name;
 }
 
-void ClassGenerator::identifier(const QString & identifier)
+void ClassGenerator::setName(const QString & newName)
 {
-    name(identifier);
+    d->name = newName;
 }
 
-QString ClassGenerator::identifier(void) const
+QString ClassGenerator::identifier() const
 {
     return name();
 }
 
-void ClassGenerator::name(const QString & newName)
+void ClassGenerator::setIdentifier(const QString & identifier)
 {
-    d->name = newName;
+    setName(identifier);
 }
 
 void ClassGenerator::addDeclaration(DeclarationPointer newDeclaration)
@@ -218,18 +202,23 @@ const QList<DeclarationPointer> & ClassGenerator::addBaseClass(const QString &
     return m_baseClasses;
 }
 
-const QList<DeclarationPointer> & ClassGenerator::inheritanceList(void) const
+const QList<DeclarationPointer> & ClassGenerator::inheritanceList() const
 {
     return d->inheritedClasses;
 }
 
-void ClassGenerator::clearInheritance(void)
+const QList< DeclarationPointer >& ClassGenerator::directInheritanceList() const
+{
+    return m_baseClasses;
+}
+
+void ClassGenerator::clearInheritance()
 {
     m_baseClasses.clear();
     d->inheritedClasses.clear();
 }
 
-void ClassGenerator::clearDeclarations(void)
+void ClassGenerator::clearDeclarations()
 {
     m_declarations.clear();
 }
@@ -293,29 +282,18 @@ KUrl & ClassGenerator::implementationUrl()
 }
 
 /// Specify license for this class
-void ClassGenerator::license(const QString & license)
+void ClassGenerator::setLicense(const QString & license)
 {
     kDebug() << "New Class: " << d->name << "Set license: " << d->license;
     d->license = license;
 }
 
 /// Get the license specified for this classes
-const QString & ClassGenerator::license(void) const
+const QString & ClassGenerator::license() const
 {
     return d->license;
 }
 
-bool ClassGenerator::addCommentCharToLicense() const
-{
-    return d->addCommentChar;
-}
-
-void ClassGenerator::setAddCommentCharToLicense(bool addcomment)
-{
-    d->addCommentChar = addcomment;
-}
-
-
 void ClassGenerator::fetchSuperClasses(DeclarationPointer derivedClass)
 {
     DUChainReadLocker lock(DUChain::lock());
@@ -353,7 +331,11 @@ ClassIdentifierPage::ClassIdentifierPage(QWizard* parent)
 
     d->classid = new Ui::NewClassDialog;
     d->classid->setupUi(this);
-
+    d->classid->addInheritancePushButton->setIcon(KIcon("list-add"));
+    d->classid->removeInheritancePushButton->setIcon(KIcon("list-remove"));
+    d->classid->moveDownPushButton->setIcon(KIcon("go-down"));
+    d->classid->moveUpPushButton->setIcon(KIcon("go-up"));
+    
     connect(d->classid->addInheritancePushButton, SIGNAL(pressed()), this, SLOT(addInheritance()));
     connect(d->classid->removeInheritancePushButton, SIGNAL(pressed()), this, SLOT(removeInheritance()));
     connect(d->classid->moveUpPushButton, SIGNAL(pressed()), this, SLOT(moveUpInheritance()));
@@ -460,7 +442,7 @@ bool ClassIdentifierPage::validatePage ( void )
 {
     //save the information in the generator
     ClassGenerator * generator = dynamic_cast<CreateClassWizard *>(wizard())->generator();
-    generator->identifier(field("classIdentifier").toString());
+    generator->setIdentifier(field("classIdentifier").toString());
     
     //Remove old base classes, and add the new ones
     generator->clearInheritance();
@@ -511,21 +493,18 @@ LicensePage::LicensePage(QWizard* parent)
     
     //Set the license selection to the previous one
     KConfigGroup config(KGlobal::config()->group("CodeGeneration"));
-    d->license->addComment->setChecked( config.readEntry( "AddCommentCharacter", true ) );
     d->license->licenseComboBox->setCurrentIndex(config.readEntry( "LastSelectedLicense", 0 ));
     //Needed to avoid a bug where licenseComboChanged doesn't get called by QComboBox if the past selection was 0
     licenseComboChanged(d->license->licenseComboBox->currentIndex());
 
     registerField("license", d->license->licenseTextEdit);
-    registerField("addComment", d->license->addComment);
 }
 
-LicensePage::~LicensePage(void)
+LicensePage::~LicensePage()
 {
     KConfigGroup config(KGlobal::config()->group("CodeGeneration"));
     //Do not save invalid license numbers'
     int index = d->license->licenseComboBox->currentIndex();
-    config.writeEntry("AddCommentCharacter", !d->license->addComment->isEnabled() || d->license->addComment->isChecked() );
     if( index >= 0 || index < d->availableLicenses.size() )
     {
         config.writeEntry("LastSelectedLicense", index);
@@ -538,7 +517,7 @@ LicensePage::~LicensePage(void)
 }
 
 // If the user entered a custom license that they want to save, save it
-bool LicensePage::validatePage(void)
+bool LicensePage::validatePage()
 {
     if(d->license->licenseComboBox->currentIndex() == (d->availableLicenses.size() - 1) && 
         d->license->saveLicense->isChecked())
@@ -548,7 +527,7 @@ bool LicensePage::validatePage(void)
 }
 
 //! Read all the license files in the global and local config dirs
-void LicensePage::initializeLicenses(void)
+void LicensePage::initializeLicenses()
 {
     kDebug() << "Searching for available licenses";
     KStandardDirs * dirs = KGlobal::dirs();
@@ -617,14 +596,11 @@ void LicensePage::licenseComboChanged(int selectedLicense)
         d->license->licenseTextEdit->clear();
         d->license->licenseTextEdit->setReadOnly(false);
         d->license->saveLicense->setEnabled(true);
-        d->license->addComment->setEnabled(true);
     }
     else
     {
         d->license->saveLicense->setEnabled(false);
         d->license->licenseTextEdit->setReadOnly(true);
-        d->license->addComment->setEnabled(false);
-        d->license->addComment->setChecked(true);
     }
     
     if(selectedLicense < 0 || selectedLicense >= d->availableLicenses.size())
@@ -633,7 +609,7 @@ void LicensePage::licenseComboChanged(int selectedLicense)
         d->license->licenseTextEdit->setText(readLicense(selectedLicense));
 }
 
-bool LicensePage::saveLicense(void)
+bool LicensePage::saveLicense()
 {
     kDebug() << "Attempting to save custom license: " << d->license->licenseName->text();
     
