@@ -54,6 +54,8 @@ K_EXPORT_PLUGIN(KDevGitFactory(KAboutData("kdevgit","kdevgit",ki18n("Git"),"0.1"
 
 using namespace KDevelop;
 
+typedef DVcsJob GitJob;
+
 namespace
 {
     
@@ -97,7 +99,7 @@ QString toRevisionName(const KDevelop::VcsRevision& rev, QString currentRevision
                 case VcsRevision::Head:
                     return "^HEAD";
                 case VcsRevision::Base:
-                    return "HEAD";
+                    return "";
                 case VcsRevision::Working:
                     return "";
                 case VcsRevision::Previous:
@@ -123,15 +125,25 @@ QString toRevisionName(const KDevelop::VcsRevision& rev, QString currentRevision
 QString revisionInterval(const KDevelop::VcsRevision& rev, const KDevelop::VcsRevision& limit)
 {
     QString ret;
-    QString srcRevisionName = toRevisionName(rev);
-    if(limit.revisionType()==VcsRevision::Special &&
-                limit.revisionValue().value<VcsRevision::RevisionSpecialType>()==VcsRevision::Start) //if we want it to the begining just put the revisionInterval
-        return ret = srcRevisionName;
-    else if(rev.revisionType()==VcsRevision::Special)
-        ret = toRevisionName(limit, srcRevisionName);
-    else
-        ret = toRevisionName(limit, srcRevisionName)+".." +srcRevisionName;
+//     qDebug() << "prrrrrrrrrr" << toRevisionName(rev, "xxx") << toRevisionName(limit, "yyy");
     
+    if(rev.revisionType()==VcsRevision::Special &&
+                rev.revisionValue().value<VcsRevision::RevisionSpecialType>()==VcsRevision::Start) //if we want it to the begining just put the revisionInterval
+        ret = toRevisionName(limit, QString());
+    else {
+        QString dst = toRevisionName(limit);
+        if(dst.isEmpty())
+            ret = dst;
+        else {
+            QString src = toRevisionName(rev, dst);
+            if(src.isEmpty())
+                ret = src;
+            else
+                ret = src+".."+dst;
+        }
+    }
+    
+//     qDebug() << "=======>" << ret;
     return ret;
 }
 
@@ -141,13 +153,18 @@ QDir urlDir(const KUrl::List& urls) { return urlDir(urls.first()); } //TODO: cou
 }
 
 GitPlugin::GitPlugin( QObject *parent, const QVariantList & )
-    : DistributedVersionControlPlugin(parent, KDevGitFactory::componentData())
+    : DistributedVersionControlPlugin(parent, KDevGitFactory::componentData()), m_oldVersion(false)
 {
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBasicVersionControl )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IDistributedVersionControl )
 
     core()->uiController()->addToolView(i18n("Git"), dvcsViewFactory());
     setObjectName("Git");
+    
+    DVcsJob* versionJob = new DVcsJob(QDir::tempPath(), this, KDevelop::OutputJob::Silent);
+    *versionJob << "git" << "--version";
+    connect(versionJob, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), SLOT(parseGitVersionOutput(KDevelop::DVcsJob*)));
+    ICore::self()->runController()->registerJob(versionJob);
 }
 
 GitPlugin::~GitPlugin()
@@ -324,13 +341,38 @@ VcsJob* GitPlugin::commit(const QString& message,
     if (localLocations.empty() || message.isEmpty())
         return errorsFound(i18n("No files or message specified"));
 
-    DVcsJob* job = new DVcsJob(dotGitDirectory(localLocations.front()), this);
+    QDir dir = dotGitDirectory(localLocations.front());
+    DVcsJob* job = new DVcsJob(dir, this);
+    KUrl::List files = (recursion == IBasicVersionControl::Recursive ? localLocations : preventRecursion(localLocations));
+    addNotVersionedFiles(dir, files);
     
     *job << "git" << "commit" << "-m" << message;
-    *job << "--" << (recursion == IBasicVersionControl::Recursive ? localLocations : preventRecursion(localLocations));
+    *job << "--" << files;
     return job;
 }
 
+void GitPlugin::addNotVersionedFiles(const QDir& dir, const KUrl::List& files)
+{
+    QStringList otherStr = getLsFiles(dir, QStringList() << "--others", KDevelop::OutputJob::Silent);
+    KUrl::List toadd, otherFiles;
+    
+    foreach(const QString& file, otherStr) {
+        KUrl v(dir.absolutePath());
+        v.addPath(file);
+        
+        otherFiles += v;
+    }
+    
+    //We add the files that are not versioned
+    foreach(const KUrl& file, files) {
+        if(otherFiles.contains(file) && QFileInfo(file.toLocalFile()).isFile())
+            toadd += file;
+    }
+    
+    VcsJob* job = add(toadd);
+    job->exec();
+}
+
 VcsJob* GitPlugin::remove(const KUrl::List& files)
 {
     if (files.isEmpty())
@@ -345,8 +387,11 @@ VcsJob* GitPlugin::remove(const KUrl::List& files)
 VcsJob* GitPlugin::log(const KUrl& localLocation,
                 const KDevelop::VcsRevision& src, const KDevelop::VcsRevision& dst)
 {
-    DVcsJob* job = new DVcsJob(urlDir(localLocation), this);
-    *job << "git" << "log" << revisionInterval(src, dst) << "--date=raw";
+    DVcsJob* job = new GitJob(dotGitDirectory(localLocation), this);
+    *job << "git" << "log" << "--date=raw";
+    QString rev = revisionInterval(dst, src);
+    if(!rev.isEmpty())
+        *job << rev;
     *job << "--" << localLocation;
     connect(job, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), this, SLOT(parseGitLogOutput(KDevelop::DVcsJob*)));
     return job;
@@ -483,10 +528,10 @@ QString GitPlugin::curBranch(const QString &repository)
     QScopedPointer<DVcsJob> job(new DVcsJob(QDir(repository), this, OutputJob::Silent));
     *job << "git" << "symbolic-ref" << "HEAD";
     if (job->exec() && job->status() == KDevelop::VcsJob::JobSucceeded) {
-        QString out = job->output();
-        int slashPos = out.lastIndexOf('/')+1;
-        kDebug() << "Getting branch list" << out.mid(slashPos, out.size()-slashPos).trimmed();
-        return out.mid(slashPos, out.size()-slashPos).trimmed();
+        QString out = job->output().trimmed();
+        
+        kDebug() << "Getting branch list" << out.right(out.size()-11);
+        return out.right(out.size()-11);
     }
     return QString();
 }
@@ -897,6 +942,21 @@ void GitPlugin::parseGitStatusOutput(DVcsJob* job)
     job->setResults(statuses);
 }
 
+void GitPlugin::parseGitVersionOutput(DVcsJob* job)
+{
+    QStringList versionString = job->output().trimmed().split(' ').last().split('.');
+    static QList<int> minimumVersion = QList<int>() << 1 << 7;
+    
+    kDebug() << "checking git version" << versionString << "against" << minimumVersion;
+    m_oldVersion = false;
+    foreach(int num, minimumVersion) {
+        QString curr = versionString.takeFirst();
+        int valcurr = curr.toInt();
+        m_oldVersion |= valcurr<num;
+    }
+    kDebug() << "the current git version is old: " << m_oldVersion;
+}
+
 QStringList GitPlugin::getLsFiles(const QDir &directory, const QStringList &args,
     KDevelop::OutputJob::OutputJobVerbosity verbosity)
 {
@@ -961,23 +1021,22 @@ VcsStatusInfo::State GitPlugin::messageToState(const QString& msg)
     return ret;
 }
 
-StandardCopyJob::StandardCopyJob(IPlugin* parent, const KUrl& source, const KUrl& dest,
+StandardJob::StandardJob(IPlugin* parent, KJob* job,
                                  OutputJob::OutputJobVerbosity verbosity)
     : VcsJob(parent, verbosity)
-    , m_source(source), m_dest(dest)
+    , m_job(job)
     , m_plugin(parent)
     , m_status(JobNotStarted)
 {}
 
-void StandardCopyJob::start()
+void StandardJob::start()
 {
-    KIO::CopyJob* job=KIO::copy(m_source, m_dest);
-    connect(job, SIGNAL(result(KJob*)), SLOT(result(KJob*)));
-    job->start();
+    connect(m_job, SIGNAL(result(KJob*)), SLOT(result(KJob*)));
+    m_job->start();
     m_status=JobRunning;
 }
 
-void StandardCopyJob::result(KJob* job)
+void StandardJob::result(KJob* job)
 {
     m_status=job->error() == 0? JobSucceeded : JobFailed; emitResult();
 }
@@ -985,15 +1044,19 @@ void StandardCopyJob::result(KJob* job)
 VcsJob* GitPlugin::copy(const KUrl& localLocationSrc, const KUrl& localLocationDstn)
 {
     //TODO: Probably we should "git add" after
-    return new StandardCopyJob(this, localLocationSrc, localLocationDstn, KDevelop::OutputJob::Silent);
+    return new StandardJob(this, KIO::copy(localLocationSrc, localLocationDstn), KDevelop::OutputJob::Silent);
 }
 
 VcsJob* GitPlugin::move(const KUrl& source, const KUrl& destination)
 {
-    DVcsJob* job = new DVcsJob(urlDir(source), this, KDevelop::OutputJob::Verbose);
-    {
+    QDir dir = urlDir(source);
+    QStringList otherStr = getLsFiles(dir, QStringList() << "--others" << "--" << source.toLocalFile(), KDevelop::OutputJob::Silent);
+    if(otherStr.isEmpty()) {
+        DVcsJob* job = new DVcsJob(dir, this, KDevelop::OutputJob::Verbose);
         *job << "git" << "mv" << source.toLocalFile() << destination.toLocalFile();
         return job;
+    } else {
+        return new StandardJob(this, KIO::move(source, destination), KDevelop::OutputJob::Silent);
     }
 }
 
