@@ -73,6 +73,8 @@
 #include "svnimportmetadatawidget.h"
 #include "svncheckoutmetadatawidget.h"
 #include <vcs/vcspluginhelper.h>
+#include <vcs/widgets/standardvcslocationwidget.h>
+#include "svnlocationwidget.h"
 
 K_PLUGIN_FACTORY(KDevSvnFactory, registerPlugin<KDevSvnPlugin>();)
 K_EXPORT_PLUGIN(KDevSvnFactory(KAboutData("kdevsubversion", "kdevsubversion", ki18n("Subversion"), "0.1", ki18n("Support for Subversion version control systems"), KAboutData::License_GPL)))
@@ -507,4 +509,9 @@ void KDevSvnPlugin::ctxCheckout()
     }
 }
 
+KDevelop::VcsLocationWidget* KDevSvnPlugin::vcsLocation(QWidget* parent) const
+{
+    return new SvnLocationWidget(parent);
+}
+
 #include "kdevsvnplugin.moc"
