@@ -39,8 +39,6 @@ namespace Sublime {
     class AreaIndex;
 }
 
-#define EMPTY_DOCUMENT_URL i18n("Untitled")
-
 namespace KDevelop {
 
 class MainWindow;
@@ -113,6 +111,9 @@ public:
     virtual bool openDocument(IDocument* doc,
                               const KTextEditor::Range& range = KTextEditor::Range::invalid(),
                               DocumentActivationParams activationParams = 0);
+                              
+    virtual KTextEditor::Document* globalTextEditorInstance();
+    
 public Q_SLOTS:
     /**Opens a new or existing document.
     @param url The full Url of the document to open. If it is empty, a dialog to choose the document will be opened.
@@ -120,7 +121,8 @@ public Q_SLOTS:
     @param activationParams Indicates whether to fully activate the document.*/
     virtual Q_SCRIPTABLE IDocument* openDocument( const KUrl &url,
             const KTextEditor::Range& range = KTextEditor::Range::invalid(),
-            DocumentActivationParams activationParams = 0);
+            DocumentActivationParams activationParams = 0,
+            const QString& encoding = "");
 
     virtual Q_SCRIPTABLE IDocument* openDocumentFromText( const QString& data );
     
