@@ -72,19 +72,12 @@ Manager::Manager(KCmdLineArgs* args) : m_total(0), m_args(args), m_allFilesAdded
 void Manager::init()
 {
     KUrl::List includes;
-    KUrl dir;
 
     if(m_args->count() == 0) {
         std::cerr << "Need directory to duchainify" << std::endl;
         QCoreApplication::exit(1);
     }
 
-    for(int i=0; i<m_args->count(); i++)
-    {
-        QString arg=m_args->arg(i);
-        dir=KUrl(arg);
-    }
-
     verbose=m_args->isSet("verbose");
     warnings=m_args->isSet("warnings");
 
@@ -135,15 +128,22 @@ void Manager::init()
         }
     }
 
-    m_args->clear();
+    for(int i=0; i<m_args->count(); i++)
+    {
+        addToBackgroundParser(m_args->arg(i), (TopDUContext::Features)features);
+    }
 
-    addToBackgroundParser(dir.toLocalFile(), (TopDUContext::Features)features);
     m_allFilesAdded = 1;
 
     if ( m_total ) {
         std::cout << "Added " << m_total << " files to the background parser" << std::endl;
+        if (m_waiting.isEmpty()) {
+            std::cout << "ready" << std::endl;
+            QApplication::quit();
+        }
     } else {
         std::cout << "no files added to the background parser" << std::endl;
+        QCoreApplication::exit(0);
     }
 }
 
@@ -220,7 +220,7 @@ int main(int argc, char** argv)
     Manager manager(args);
 
     QTimer::singleShot(0, &manager, SLOT(init()));
-    app.exec();
+    return app.exec();
 }
 
 #include "main.moc"
