@@ -22,7 +22,6 @@
 #ifndef IBASICVERSIONCONTROL_H
 #define IBASICVERSIONCONTROL_H  
 
-#include <interfaces/iextension.h>
 #include <KDE/KUrl>
 #include "../vcsrevision.h"
 #include "../vcsdiff.h"
@@ -35,6 +34,8 @@ namespace KDevelop
 class VcsJob;
 class VcsLocation;
 class VcsImportMetadataWidget;
+class VcsLocationWidget;
+
 /**
  * This is the basic interface that all Version Control or Source Code Management
  * plugins need to implement. None of the methods in this interface are optional.
@@ -188,12 +189,12 @@ public:
      * log events are available. The fetchResults method will return a QList<QVariant>
      * where the QVariant is a KDevelop::VcsEvent.
      *
-     * @param rev List @p rev and earlier. The default is HEAD.
+     * @param rev List @p rev and earlier.
      * @param limit Restrict to the most recent @p limit entries. Note that the
      * limit is @e advisory and may be ignored.
      */
     virtual VcsJob* log( const KUrl& localLocation,
-                         const VcsRevision& rev = VcsRevision::createSpecialRevision( VcsRevision::Head ),
+                         const VcsRevision& rev,
                          unsigned long limit = 0 ) = 0;
 
     /**
@@ -203,13 +204,13 @@ public:
      * log events are available. The fetchResults method will return a QList<QVariant>
      * where the QVariant is a KDevelop::VcsEvent.
      *
-     * @param rev List @p rev and earlier. The default is HEAD.
+     * @param rev List @p rev and earlier. The default is BASE.
      * @param limit Do not show entries earlier than @p limit. Note that the
-     * limit is @e advisory and may be ignored.
+     * limit is @e advisory and may be ignored. The default is the first revision.
      */
     virtual VcsJob* log( const KUrl& localLocation,
-                         const VcsRevision& rev,
-                         const VcsRevision& limit ) = 0;
+                         const VcsRevision& rev = VcsRevision::createSpecialRevision( VcsRevision::Base ),
+                         const VcsRevision& limit= VcsRevision::createSpecialRevision( VcsRevision::Start ) ) = 0;
 
     /**
      * Annotate each line of the given local url at the given revision
@@ -245,12 +246,13 @@ public:
      * @param destinationDirectory location of the created working copy (local repository)
      */
     virtual VcsJob* createWorkingCopy(const VcsLocation & sourceRepository, const KUrl & destinationDirectory, RecursionMode recursion = IBasicVersionControl::Recursive) = 0;
+    
+    virtual VcsLocationWidget* vcsLocation(QWidget* parent) const=0;
 
 };
 
 }
 
-KDEV_DECLARE_EXTENSION_INTERFACE_NS( KDevelop, IBasicVersionControl, "org.kdevelop.IBasicVersionControl" )
 Q_DECLARE_INTERFACE( KDevelop::IBasicVersionControl, "org.kdevelop.IBasicVersionControl" )
 
 #endif
